<?php

namespace Metropolitan\Booking\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Metropolitan\Booking\Actions\BookingExim;
use Metropolitan\Booking\Http\Requests\BookingEximRequest;

/**
 * Admin web controller class.
 */
class BookingEximController extends BaseController
{
    /**
     * Action controller function for booking.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BookingEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = BookingExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('booking:booking.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('booking/booking/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('booking/booking/' . $exim))
                ->redirect();
        }
    }
}
